@@ -3,7 +3,7 @@ from .analysis_bilibili import b23_extract, bili_keyword
 from nonebot import on_regex
 from nonebot.adapters import Bot, Event
 
-analysis_bili = on_regex("(b23.tv)|(bilibili.com/video)|(bilibili.com/bangumi)|(^(BV|bv)([0-9A-Za-z]{10}))|(^(av|AV)([0-9]+)(/.*|\\?.*|)$)|(\[\[QQ小程序\]哔哩哔哩\])|(QQ小程序&amp;#93;哔哩哔哩)|(QQ小程序&#93;哔哩哔哩)")
+analysis_bili = on_regex("(b23.tv)|(bilibili.com)|(^(CV|cv)(\d+))|(^(BV|bv)([0-9A-Za-z]{10}))|(^(av|AV)([0-9]+)(/.*|\\?.*|)$)|(\[\[QQ小程序\]哔哩哔哩\])|(QQ小程序&amp;#93;哔哩哔哩)|(QQ小程序&#93;哔哩哔哩)")
 
 @analysis_bili.handle()
 async def analysis_main(bot: Bot, event: Event, state: dict):
